==> nextcloud-13.0.1.tgz: nextcloud/apps/survey_client/l10n/es_EC.js <==
OC.L10N.register(
    "survey_client",
    {
    "Usage survey" : "Encuesta de uso",
    "Sent on: {on}" : "Enviado el: {on}",
    "An error occurred while sending your report." : "Se presentó un error al enviar tu reporte.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Lista de aplicaciones <em>(para cada aplicacion: nombre, versión, estado de activación)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Ambiente de la base de datos <em>(tipo, versión, tamaño de la base de datos) </em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Información de encripción <em>(¿Está habilitada? ¿Cuál es el módulo predeterminado?)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Número de elementos compartidos <em>(por tipo y configuración de permisos)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "Ambiente de PHP <em>(versión, límite de memoria, tiempo max. de ejecución, tamaño max. de archivos)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Detalles de la instancia del servidor <em>(versión, memcache usado, estado de bloqueo/previsualización/avatares)</em>",
    "Statistic <em>(number of: files, users, storages per type, comments and tags)</em>" : "Estadística <em>(número de: archivos, usuarios, almacenamientos por tipo, comentarios y etiquetas)</em>",
    "Help improve Nextcloud" : "Ayúdanos a mejorar a Nextcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "¿Quieres ayudarnos a mejorar a Nextcloud  proporcionándonos datos anónimos acerca de tu configuración y uso? Puedes deshabilitarlo en cualquier momento en la configuración de administración.",
    "Not now" : "No ahora",
    "Send usage" : "Enviar uso",
    "Never" : "Nunca",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Puedes ayudar a mejorar Nextcloud enviándonos algunos datos de tu configuración actual y uso.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Tomamos tu privacidad muy seriamente. El envío de datos está deshabilitado por omisión y si decides habilitarlo, primero se harán anónimos y tendrás la opción de decidir que cosas quieres compartir. Tras recibir un reporte nuevo, el reporte anterior será eliminado. Carga un reporte nuevo para borrar todos los datos actualmente almacenados en el servidor. ",
    "Send new report now" : "Enviar un nuevo reporte ahora",
    "Send usage survey monthly" : "Enviar la encuesta de uso mensual",
    "Data to send" : "Datos a enviar",
    "Last report" : "Último reporte",
    "Sent on: %s" : "Enviado el: %s",
    "App list <em>(for each app: name, version, is enabled?)</em>" : "Lista de aplicaciones<em>(para cada aplicación: nombre, versión, está habilitada?)</em>",
    "Server instance details <em>(version, memcache used, locking/previews/avatars enabled?)</em>" : "Detalles del servidor de instancia <em>(versión, memoria caché usada, ¿bloqueo/previsualización/avatares habilitados?)</em>",
    "You can help us to improve Nextcloud by sending us some data about your current setup and usage." : "Puedes ayudarnos a mejorar a Nextcloud al mandarnos algunos datos de tu configuración actual y su uso.",
    "We take your privacy seriously. The data is anonymized and you can enable/disable it at any time, by default it is always disabled. Below you can also adjust what kind of data is sent and always see the last report sent to us. When the server receives a new report of your instance, all entries from previous reports are removed. If you disable one of the settings below, you can send a new report, which will delete the data that is currently stored on the server." : "Tomamos tu privacidad muy seriamente. Los datos se hacen anónimos y puedes habilitar/deshabilitar esta funcionalidad en cualquier momento, por omisión, está siempre deshabilitada. En la parte inferior puedes ajustar que tipo de datos son enviados y ver el reporte que se nos envía. Cuando el servidor recibe un nuevo reporte de tu instancia, todas las entradas de reportes previos son eliminadas. Si deshabilitars una de las configuraciones de abajo, puedes enviar un nuevo reporte, que borrará los datos que actualmente están almacenados en el servidor. "
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-25.0.5.tgz: nextcloud/apps/survey_client/l10n/es_EC.js <==
OC.L10N.register(
    "survey_client",
    {
    "Last report sent on: {on}" : "Último reporte enviado el: {on}",
    "An error occurred while sending your report." : "Se presentó un error al enviar tu reporte.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Lista de aplicaciones <em>(para cada aplicacion: nombre, versión, estado de activación)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Ambiente de la base de datos <em>(tipo, versión, tamaño de la base de datos) </em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Información de encripción <em>(¿Está habilitada? ¿Cuál es el módulo predeterminado?)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Número de elementos compartidos <em>(por tipo y configuración de permisos)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "Ambiente de PHP <em>(versión, límite de memoria, tiempo max. de ejecución, tamaño max. de archivos)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Detalles de la instancia del servidor <em>(versión, memcache usado, estado de bloqueo/previsualización/avatares)</em>",
    "Usage survey" : "Encuesta de uso",
    "Help improve Nextcloud" : "Ayúdanos a mejorar a Nextcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "¿Quieres ayudarnos a mejorar a Nextcloud  proporcionándonos datos anónimos acerca de tu configuración y uso? Puedes deshabilitarlo en cualquier momento en la configuración de administración.",
    "Not now" : "No ahora",
    "Send usage" : "Enviar uso",
    "Never" : "Nunca",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Puedes ayudar a mejorar Nextcloud enviándonos algunos datos de tu configuración actual y uso.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Tomamos tu privacidad muy seriamente. El envío de datos está deshabilitado por omisión y si decides habilitarlo, primero se harán anónimos y tendrás la opción de decidir que cosas quieres compartir. Tras recibir un reporte nuevo, el reporte anterior será eliminado. Carga un reporte nuevo para borrar todos los datos actualmente almacenados en el servidor. ",
    "Send new report now" : "Enviar un nuevo reporte ahora",
    "Send usage survey monthly" : "Enviar la encuesta de uso mensual",
    "Data to send" : "Datos a enviar",
    "Last report sent on: %s" : "Último reporte enviado el: %s",
    "Last report" : "Último reporte"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
